@@ -5,7 +5,7 @@ from debmutate.control import (
     parse_relations,
     ControlEditor,
     )
-from lintian_brush.fixer import report_result
+from lintian_brush.fixer import report_result, LintianIssue
 
 
 uses_debhelper = False
@@ -25,12 +25,16 @@ with ControlEditor() as updater:
                 if any(r.name == '${misc:Depends}' for r in relation):
                     break
             else:
-                binary["Depends"] = add_dependency(
-                    binary.get("Depends", ''), "${misc:Depends}")
-                misc_depends_added.append(binary["Package"])
+                issue = LintianIssue(
+                    updater.source, 'debhelper-but-no-misc-depends',
+                    info=binary['Package'])
+                if issue.should_fix():
+                    binary["Depends"] = add_dependency(
+                        binary.get("Depends", ''), "${misc:Depends}")
+                    misc_depends_added.append(binary["Package"])
+                    issue.report_fixed()
 
 
 report_result(
     "Add missing ${misc:Depends} to Depends for %s." %
-    ", ".join(misc_depends_added),
-    fixed_lintian_tags=['debhelper-but-no-misc-depends'])
+    ", ".join(misc_depends_added))
