@@ -1,13 +1,15 @@
 #!/usr/bin/python3
 
 from lintian_brush.rules import update_rules
-from lintian_brush.fixer import report_result, fixed_lintian_tag
+from lintian_brush.fixer import report_result, LintianIssue
 
 
 def update_line(line, target):
     if line.strip() == b'dh_clean -k':
-        fixed_lintian_tag('source', "dh-clean-k-is-deprecated", '')
-        return b'dh_prep'
+        issue = LintianIssue('source', "dh-clean-k-is-deprecated", '')
+        if issue.should_fix():
+            issue.report_fixed()
+            return b'dh_prep'
     return line
 
 
