@@ -18,6 +18,7 @@
 """Debianize a package."""
 
 from debian.changelog import Changelog, Version, get_maintainer, format_date
+from debmutate.control import ensure_some_version
 from debian.deb822 import Deb822
 import os
 import re
@@ -25,13 +26,17 @@ import sys
 import warnings
 
 
-def write_debhelper_rules_template(path):
+def write_debhelper_rules_template(path, buildsystem):
+    dh_args = ['$@']
+    if buildsystem:
+        dh_args.append('--buildsystem=%s' % buildsystem)
+
     with open(path, 'w') as f:
         f.write("""\
 #!/usr/bin/make -f
 
 %:
-\tdh $@
+\tdh """ + ' '.join(dh_args) + """
 """)
     os.chmod(path, 0o755)
 
@@ -46,7 +51,8 @@ def write_control_template(path, source, binaries):
 
 def write_changelog_template(path, source_name, version, wnpp_bugs=None):
     if wnpp_bugs:
-        closes = ' Closes: ' % ', '.join(['#%d' for bug in wnpp_bugs])
+        closes = ' Closes: ' + ', '.join(
+            [('#%d' % (bug, )) for bug in wnpp_bugs])
     else:
         closes = ''
     cl = Changelog()
@@ -169,7 +175,7 @@ def main(argv=None):
     if dirty_tracker:
         dirty_tracker.mark_clean()
 
-    if os.path.exists('debian'):
+    if os.path.exists('debian') and list(os.listdir('debian')):
         note('%s: A debian directory already exists. '
              'Run lintian-brush instead?', wt.abspath(subpath))
         return 1
@@ -247,11 +253,23 @@ def main(argv=None):
             'debhelper-compat (= %d)' % maximum_debhelper_compat_version(
                 compat_release))
 
+        if buildsystem and buildsystem.name == 'setup.py':
+            source['Build-Depends'] = ensure_some_version(
+                source['Build-Depends'],
+                'python3-all')
+            dh_buildsystem = 'pybuild'
+        else:
+            dh_buildsystem = None
+
         initial_files = []
         try:
-            wt.mkdir(osutils.pathjoin(subpath, 'debian'))
-            write_debhelper_rules_template('debian/rules')
-            initial_files.append('debian/rules')
+            debian_path = osutils.pathjoin(subpath, 'debian')
+            if not wt.has_filename(debian_path):
+                wt.mkdir(debian_path)
+            write_debhelper_rules_template(
+                os.path.join(debian_path, 'rules'),
+                dh_buildsystem)
+            initial_files.append(os.path.join(debian_path, 'rules'))
             write_control_template('debian/control', source, binaries)
             initial_files.append('debian/control')
             write_changelog_template(
