@@ -19,39 +19,93 @@
 
 from debmutate.deb822 import Deb822
 import sys
-from typing import Optional, Tuple, Union
+from typing import Optional, Tuple, Union, List, Any
 
 from . import (
     DEFAULT_MINIMUM_CERTAINTY,
     certainty_sufficient,
     )
-from .lintian_overrides import override_exists as _override_exists
+from .lintian_overrides import (
+    get_overrides,
+    LintianOverride,
+    load_renamed_tags,
+    )
 
 
 from debian.changelog import Version
 import os
 
 
-_fixed_lintian_tags = []
+class LintianIssue(object):
+    """Represents a lintian issue."""
+
+    def __init__(
+            self,
+            target: Union[Deb822, Tuple[str, str]],
+            tag: str, info: Optional[Union[str, Tuple[str, ...]]] = None):
+        if isinstance(target, Deb822):
+            if 'Source' in target:
+                target = ('source', target['Source'])
+            elif 'Package' in target:
+                target = ('binary', target['Package'])
+            else:
+                raise ValueError(
+                    'unable to determine source/binary package from target')
+        elif target == 'source':
+            target = ('source', None)
+        if isinstance(info, tuple):
+            info = ' '.join(info)
+        self.target = target
+        self.info = info
+        self.tag = tag
+
+    def override_exists(self):
+        return _override_exists(
+            tag=self.tag, info=self.info, type=self.target[0],
+            package=self.target[1])
+
+    def should_fix(self):
+        return not self.override_exists()
+
+    def report_fixed(self):
+        _fixed_lintian_tags.append((self.target, self.tag, self.info))
+
+    def __repr__(self):
+        return "%s(target=%r, tag=%r, info=%r)" % (
+            type(self).__name__, self.target, self.tag, self.info)
+
+
+_fixed_lintian_tags: List[Any] = []
+_present_overrides: Optional[List[LintianOverride]] = None
+_tag_renames = None
+
+
+def _override_exists(
+        tag: str, info: Optional[str] = None,
+        package: Optional[str] = None,
+        type: Optional[str] = None,
+        arch: Optional[str] = None) -> bool:
+    global _present_overrides, _tag_renames
+    if _present_overrides is None:
+        _present_overrides = list(get_overrides())
+    if not _present_overrides:
+        return False
+    if _tag_renames is None:
+        _tag_renames = load_renamed_tags()
+    for override in _present_overrides:
+        if _tag_renames.get(override.tag) == tag:
+            tag = override.tag
+        if override.matches(package=package, info=info, tag=tag, arch=arch,
+                            type=type):
+            return True
+    return False
 
 
 def fixed_lintian_tag(
         target: Union[Deb822, Tuple[str, str]],
         tag: str, info: Optional[Union[str, Tuple[str, ...]]] = None):
     """Register a lintian tag as being fixed."""
-    if isinstance(target, Deb822):
-        if 'Source' in target:
-            target = ('source', target['Source'])
-        elif 'Package' in target:
-            target = ('binary', target['Package'])
-        else:
-            raise ValueError(
-                'unable to determine source/binary package from target')
-    elif target == 'source':
-        target = ('source', )
-    if isinstance(info, tuple):
-        info = ' '.join(info)
-    _fixed_lintian_tags.append((target, tag, info))
+    LintianIssue(target, tag, info).report_fixed()
 
 
 def fixed_lintian_tags():
@@ -61,8 +115,9 @@ def fixed_lintian_tags():
 
 def reset() -> None:
     """Reset any global state that may exist."""
-    global _fixed_lintian_tags
+    global _fixed_lintian_tags, _present_overrides
     _fixed_lintian_tags = []
+    _present_overrides = None
 
 
 def report_result(description=None, certainty=None, patch_name=None):
@@ -122,23 +177,6 @@ def warn(msg):
     sys.stderr.write('%s\n' % msg)
 
 
-def override_exists(
-        target: Union[Deb822, Tuple[str, str]],
-        tag: str, info: Optional[str] = None):
-    if isinstance(target, Deb822):
-        if 'Source' in target:
-            target = ('source', target['Source'])
-        elif 'Package' in target:
-            target = ('binary', target['Package'])
-        else:
-            raise ValueError(
-                'unable to determine source/binary package from target')
-    elif target == 'source':
-        target = ('source', None)
-    return _override_exists(
-        tag=tag, info=info, type=target[0], package=target[1])
-
-
 def diligence():
     return int(os.environ.get('DILIGENCE', '0'))
 
